.. -*- coding: utf-8 -*-

===========================
GNU Mailman Acknowledgments
===========================

Copyright (C) 1998-2012 by the Free Software Foundation, Inc.


Core Developers
===============

The following folks are or have been core developers of Mailman (in reverse
alphabetical order):

* Barry Warsaw, Mailman's yappy guard dog
* Mark Sapiro, Mailman's compulsive responder
* Tokio Kikuchi, Mailman's weatherman
* John Viega, Mailman's inventor
* Thomas Wouters, Mailman's Dutch treat
* Harald Meland, Norse Mailman
* Ken Manheimer, Mailman's savior
* Scott Cotton, Cookie-Monster


Steering Committee
==================

The Mailman Steering Committee can be contacted directly via
mailman-cabal@python.org


Copyright Assignees
===================

Here is the list of other contributors who have donated large bits of
code, and have assigned copyright for contributions to the FSF:

* Juan Carlos Rey Anaya
* Andrija Arsic
* Richard Barrett
* Jimmy Bergman
* Stephan Berndts
* Norbert Bollow
* Joe Dugan
* Ethan Mindlace Fremen
* Florian Fuchs
* Ben Gertzfield
* Victoriano Giralt
* Stephen Goss
* Mads Kiilerich
* Cedric Knight
* Patrick Ben Koetter
* The Dragon De Monsyne
* Les Niles
* Reed O'Brien
* Terri Oda
* Simone Piunno
* Claudia Schmidt
* Andreas Schosser
* Richard Wackerbarth


Special Thanks
==============

Very special thanks to Andrija Arsic for his winning new GNU Mailman logos.

Thanks also go to the following people for their important contributions in
other aspects of the Mailman project:

* Brad Knowles
* JC Dill
* Clytie Siddall

Thanks also to Dragon for his original Mailman logo contribution, and to Terri
Oda for the neat shortcut icon and the member documentation.

Control.com sponsored development of several Mailman 2.1 features, including
topics filters, external membership sources, and initial virtual mailing list
support.  My thanks especially to Dan Pierson and Ken Crater from Control.com.

Here is the list of other people who have contributed useful ideas,
suggestions, bug fixes, testing, etc., or who have been very helpful in
answering questions on mailman-users.  Please let me know if you have been
left off the list!

* David Abrahams
* William Ahern
* Terry Allen
* Jose Paulo Moitinho de Almeida
* Sven Anderson
* Matthias Andree
* Anton Antonov
* Mike Avery
* Stonewall Ballard
* Moreno Baricevic
* Jimmy Bergman
* Jeff Berliner
* Stuart Bishop
* David Blomquist
* Bojan
* Søren Bondrup
* Grant Bowman
* Alessio Bragadini
* J\. D\. Bronson
* Stan Bubrouski
* Daniel Buchmann
* Ben Burnett
* Ted Cabeen
* Mentor Cana
* John Carnes
* Julio A. Cartaya
* Claudio Cattazzo
* Donn Cave
* David Champion
* Hye-Shik Chang
* Eric D. Christensen
* Tom G. Christensen
* Paul Cox
* Stefaniu Criste
* Robert Daeley
* Ned Dawes
* Emilio Delgado
* John Dennis
* Stefan Divjak
* Maximillian Dornseif
* Fred Drake
* Maxim Dzumanenko
* Piarres Beobide Egaña
* Rob Ellis
* Kerem Erkan
* Fil
* Patrick Finnerty
* Bob Fleck
* Erik Forsberg
* Darrell Fuhriman
* Robert Garrigós
* Carson Gaspar
* Pascal GEORGE
* Vadim Getmanshchuk
* David Gibbs
* Dmitri I GOULIAEV
* Terry Grace
* Federico Grau
* Pekka Haavisto
* David Habben
* Stig Hackvan
* Jeff Hahn
* Terry Hardie
* Paul Hebble
* Tollef Fog Heen
* Peer Heinlein
* James Henstridge
* Walter Hop
* Bert Hubert
* Henny Huisman
* Jeremy Hylton
* Ikeda Soji
* Rostyk Ivantsiv
* Ron Jarrell
* Matthias Juchem
* Tamito KAJIYAMA
* Nino Katic
* SHIGENO Kazutaka
* Ashley M. Kirchner
* Matthias Klose
* Harald Koch
* Patrick Koetter
* Eddie Kohler
* Chris Kolar
* Uros Kositer
* Andrew Kuchling
* Ricardo Kustner
* L'homme Moderne
* Sylvain Langlade
* Ed Lau
* J C Lawrence
* Greg Lindahl
* Christopher P. Lindsey
* Martin von Loewis
* Dario Lopez-Kästen
* Tanner Lovelace
* Jay Luker
* Gergely Madarasz
* Luca Maranzano
* John A. Martin
* Andrew Martynov
* Jason R. Mastaler
* Michael Mclay
* Michael Meltzer
* Marc MERLIN
* Nigel Metheringham
* Dan Mick
* Garey Mills
* Martin Mokrejs
* Michael Fischer v. Mollard
* David Martínez Moreno
* Dirk Mueller
* Jonas Muerer
* Erik Myllymaki
* Balazs Nagy
* Moritz Naumann
* Dale Newfield
* Hrvoje Niksic
* Les Niles
* Mike Noyes
* David B. O'Donnell
* Timothy O'Malley
* "office"
* Dan Ohnesorg
* Gerald Oskoboiny
* Eva Österlind
* Toni Panadès
* Jon Parise
* Chris Pepper
* Tim Peters
* Joe Peterson
* PieterB
* Rodolfo Pilas
* Skye Poier
* Martin Pool
* Don Porter
* Francesco Potortì
* Bob Puff
* Michael Ranner
* John Read
* Sean Reifschneider
* Christian Reis
* Ademar de Souza Reis, Jr.
* Bernhard Reiter
* Stephan Richter
* Tristan Roddis
* Heiko Rommel
* Luigi Rosa
* Guido van Rossum
* Nicholas Russo
* Chris Ryan
* Cabel Sasser
* Bartosz Sawicki
* Kai Schaetzl
* Karoly Segesdi
* Gleydson Mazioli da Silva
* Pasi Sjöholm
* Chris Snell
* Mikhail Sobolev
* Greg Stein
* Dale Stimson
* Students of HIT <mailman-cn@mail.cs.hit.edu.cn>
* Szabolcs Szigeti
* Vizi Szilard
* David T-G
* Owen Taylor
* Danny Terweij
* Jim Tittsler
* Todd (Freedom Lover)
* Roger Tsang
* Chuq Von Rospach
* Jens Vagelpohl
* Valia V. Vaneeva
* Anti Veeranna
* Todd Vierling
* Bill Wagner
* Greg Ward
* Mark Weaver
* Kathleen Webb
* Florian Weimer
* Ousmane Wilane
* Dan Wilder
* Seb Wills
* Dai Xiaoguang
* Ping Yeh
* YASUDA Yukihiro
* Michael Yount
* Blair Zajac
* Mikhail Zabaluev
* Noam Zeilberger
* Daniel Zeiss
* Todd Zullinger

And everyone else on mailman-developers@python.org and
mailman-users@python.org!  Thank you, all.
